"""
RCSid:
	$Id: conf.py,v 1.12 2021/04/09 00:18:14 sjg Exp $

	@(#) Copyright (c) 2012 Simon J. Gerraty

	This file is provided in the hope that it will
	be of use.  There is absolutely NO WARRANTY.
	Permission to copy, redistribute or otherwise
	use this file is hereby granted provided that 
	the above copyright notice and this notice are
	left intact. 
      
	Please send copies of changes and bug-fixes to:
	sjg@crufty.net

"""

import os
import vars

def host_target():
    u = os.uname()
    return '{0}{1}-{2}'.format(u[0].lower(), u[2].split('.')[0], u[-1])

def loadConfig(name, conf={}):
    """Add key value pairs into conf from a file

    The config file consists of records like::

    set_a_string = one and two
    set_a_list [=] one,two,three
    add_to_list [+=] four,five

    trailing white-space is stripped, and list values
    split on ``,``
    """
    cf = open(name, 'r')
    vs = vars.Vars(conf)
    vs.set('config', name)
    vs.set('config_dir', '${config:tA:H}')
    splits = conf.get('list_split', ',')
    for line in cf:
        line = line.strip()
        if line.startswith('#'):
            continue
        if line.find('[+=]') > 0:
            # value is a list to append
            k,v = line.split('[+=]', 1)
            k = vs.subst(k).strip()
            if not k in conf:
                conf[k] = []
            conf[k] += vs.subst(v).strip().split(splits)
            vs.set(k, conf[k])
        elif line.find('[=]') > 0:
            # value is a list
            k,v = line.split('[=]', 1)
            k = vs.subst(k).strip()
            conf[k] = vs.subst(v).strip().split(splits)
            vs.set(k, conf[k])
        elif line.find('=') > 0:
            k,v = line.split('=', 1)
            k = vs.subst(k).strip()
            conf[k] = vs.subst(v).strip()
            vs.set(k, conf[k])
    return conf

if __name__ == '__main__':
    import getopt
    import sys

    opts,args = getopt.getopt(sys.argv[1:], 'dc:')
    debug = 0
    conf = {}
    for o,a in opts:
        if o == '-d':
            debug += 1
        elif o == '-c':
            conf['debug'] = debug
            conf = loadConfig(a, conf)

    for k,v in conf.items():
        print('{} = {}'.format(k,v))
